pub struct FormError { /* private fields */ }Trait Implementations
Sourceimpl Extend<FieldError> for FormError
impl Extend<FieldError> for FormError
Sourcefn extend<T: IntoIterator<Item = FieldError>>(&mut self, other: T)
fn extend<T: IntoIterator<Item = FieldError>>(&mut self, other: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl From<FieldError> for FormError
impl From<FieldError> for FormError
Sourcefn from(err: FieldError) -> Self
fn from(err: FieldError) -> Self
Converts to this type from the input type.